@@ -2,7 +2,7 @@ from django.urls import path
 
 from netbox.views.generic import ObjectChangeLogView
 
-from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume
+from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, LinuxVolume
 from netbox_storage.views import (
     # Drive View
     DriveListView,
@@ -53,6 +53,14 @@ from netbox_storage.views import (
     LogicalVolumeBulkDeleteView,
     LogicalVolumeView,
     LogicalVolumeDeleteView,
+    # LinuxVolume
+    LinuxVolumeListView,
+    LinuxVolumeEditView,
+    LinuxVolumeBulkImportView,
+    LinuxVolumeBulkEditView,
+    LinuxVolumeBulkDeleteView,
+    LinuxVolumeView,
+    LinuxVolumeDeleteView,
 )
 
 app_name = "netbox_storage"
@@ -161,4 +169,21 @@ urlpatterns = [
         name="logicalvolume_changelog",
         kwargs={"model": LogicalVolume},
     ),
+    #
+    # LinuxVolume urls
+    #
+    path("linuxvolume/", LinuxVolumeListView.as_view(), name="linuxvolume_list"),
+    path("linuxvolume/add/", LinuxVolumeEditView.as_view(), name="linuxvolume_add"),
+    path("linuxvolume/import/", LinuxVolumeBulkImportView.as_view(), name="linuxvolume_import"),
+    path("linuxvolume/edit/", LinuxVolumeBulkEditView.as_view(), name="linuxvolume_bulk_edit"),
+    path("linuxvolume/delete/", LinuxVolumeBulkDeleteView.as_view(), name="linuxvolume_bulk_delete"),
+    path("linuxvolume/<int:pk>/", LinuxVolumeView.as_view(), name="linuxvolume"),
+    path("linuxvolume/<int:pk>/edit/", LinuxVolumeEditView.as_view(), name="linuxvolume_edit"),
+    path("linuxvolume/<int:pk>/delete/", LinuxVolumeDeleteView.as_view(), name="linuxvolume_delete"),
+    path(
+        "linuxvolume/<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="linuxvolume_changelog",
+        kwargs={"model": LinuxVolume},
+    ),
 ]
